@@ -65,6 +65,12 @@ def list_all(fritz, args):
             print("  level=%s" % device.level)
             print("  hue=%s" % device.hue)
             print("  saturation=%s" % device.saturation)
+        if device.has_blind:
+            print(" Blind:")
+            print("  level=%s" % device.level)
+            print("  levelpercentage=%s" % device.levelpercentage)
+            print("  endpositionset=%s" % device.endpositionsset)
+            
 
 
 def device_name(fritz, args):
@@ -83,6 +89,27 @@ def device_statistics(fritz, args):
     print(stats)
 
 
+def blind_set_open(fritz, args):
+    """Command to open the blinds."""
+    fritz.set_blind_open(args.ain)
+
+def blind_set_close(fritz, args):
+    """Command close the blinds."""
+    fritz.set_blind_close(args.ain)
+
+def blind_set_level_percentage(fritz, args):
+    """Command that sets the blind level as percentage."""
+    fritz.set_level_percentage(args.ain, args.level)
+
+
+def thermostat_set_target_temperature(fritz, args):
+    """Command that sets the thermostat temperature."""
+    fritz.set_target_temperature(args.ain, args.temperature)
+
+def thermostat_set_window_open(fritz, args):
+    """Command that sets the thermostats window state."""
+    fritz.set_window_open(args.ain, args.timespan)
+
 def switch_get(fritz, args):
     """Command that get the device switch state."""
     print(fritz.get_switch_state(args.ain))
@@ -191,6 +218,44 @@ def main(args=None):
     subparser.add_argument("ain", type=str, metavar="AIN", help="Actor Identification")
     subparser.set_defaults(func=device_statistics)
 
+
+    # blind
+    subparser = _sub.add_parser("blind", help="Blind commands")
+    _sub_switch = subparser.add_subparsers()
+
+    # blind open
+    subparser = _sub_switch.add_parser("open", help="open blinds")
+    subparser.add_argument("ain", type=str, metavar="AIN", help="Actor Identification")
+    subparser.set_defaults(func=blind_set_open)
+
+    # blind close
+    subparser = _sub_switch.add_parser("close", help="close blinds")
+    subparser.add_argument("ain", type=str, metavar="AIN", help="Actor Identification")
+    subparser.set_defaults(func=blind_set_close)
+
+    # blind set level in percentage
+    subparser = _sub_switch.add_parser("set_level", help="set level of blinds in percentage (0=open)")
+    subparser.add_argument("ain", type=str, metavar="AIN", help="Actor Identification")
+    subparser.add_argument("level", type=float, metavar="LEVEL", help="blind level in percentage (0=open)")
+    subparser.set_defaults(func=blind_set_level_percentage)
+
+
+    # thermostat
+    subparser = _sub.add_parser("thermostat", help="Thermostat commands")
+    _sub_switch = subparser.add_subparsers()
+
+    # thermostat target temperature
+    subparser = _sub_switch.add_parser("set_target_temperature", help="set target temperature")
+    subparser.add_argument("ain", type=str, metavar="AIN", help="Actor Identification")
+    subparser.add_argument("temperature", type=float, metavar="TEMPERATURE", help="target temperature in (C)")
+    subparser.set_defaults(func=thermostat_set_target_temperature)
+
+    # thermostat window_open
+    subparser = _sub_switch.add_parser("set_window_open", help="set window state to open")
+    subparser.add_argument("ain", type=str, metavar="AIN", help="Actor Identification")
+    subparser.add_argument("timespan", type=int, metavar="TIMESPAN", nargs='?', default=300, help="Open timespan in seconds (default=300s)")
+    subparser.set_defaults(func=thermostat_set_window_open)
+
     # switch
     subparser = _sub.add_parser("switch", help="Switch commands")
     _sub_switch = subparser.add_subparsers()
