@@ -4,6 +4,7 @@ from __future__ import print_function
 
 import hashlib
 import logging
+import time
 from xml.etree import ElementTree
 
 from requests import Session
@@ -24,15 +25,16 @@ class Fritzhome(object):
     _devices: Dict[str, FritzhomeDevice] = None
     _templates: Dict[str, FritzhomeTemplate] = None
 
-    def __init__(self, host, user, password):
+    def __init__(self, host, user, password, ssl_verify=True):
         self._host = host
         self._user = user
         self._password = password
         self._session = Session()
+        self._ssl_verify = ssl_verify
 
     def _request(self, url, params=None, timeout=10):
         """Send a request with parameters."""
-        rsp = self._session.get(url, params=params, timeout=timeout)
+        rsp = self._session.get(url, params=params, timeout=timeout, verify=self._ssl_verify)
         rsp.raise_for_status()
         return rsp.text.strip()
 
@@ -224,6 +226,12 @@ class Fritzhome(object):
 
         self._aha_request("sethkrtsoll", ain=ain, param={'param': temp})
 
+    def set_window_open(self, ain, seconds):
+        """Set the thermostate target temperature."""
+        endtimestamp =  int(time.time() + seconds)
+
+        self._aha_request("sethkrwindowopen", ain=ain, param={'endtimestamp': endtimestamp})
+
     def get_comfort_temperature(self, ain):
         """Get the thermostate comfort temperature."""
         return self._get_temperature(ain, "gethkrkomfort")
@@ -262,8 +270,12 @@ class Fritzhome(object):
 
     def set_level_percentage(self, ain, level):
         """Set level/brightness/height in interval [0,100]."""
-        # Scale percentage to [0,255] interval
-        self.set_level(ain, int(level*2.55))
+        if level < 0:
+            level = 0
+        elif level > 100:
+            level = 100
+
+        self._aha_request("setlevelpercentage", ain=ain, param={'level': int(level)})
 
     def _get_colordefaults(self, ain):
         plain = self._aha_request("getcolordefaults", ain=ain)
@@ -324,6 +336,17 @@ class Fritzhome(object):
         }
         self._aha_request("setcolortemperature", ain=ain, param=params)
 
+    #blinds
+    # states: open, close, stop
+    def _set_blind_state(self, ain, state):
+        self._aha_request("setblind", ain=ain, param={"target": state})
+    def set_blind_open(self, ain):
+        self._set_blind_state(ain, "open")
+    def set_blind_close(self, ain):
+        self._set_blind_state(ain, "close")
+    def set_blind_stop(self, ain):
+        self._set_blind_state(ain, "stop")
+
     # Template-related commands
 
     def update_templates(self):
